@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,12 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef __LIBGCMD_DATA_H__
 #define __LIBGCMD_DATA_H__
 
+G_BEGIN_DECLS
 
 void
 gnome_cmd_data_set_string (const gchar *path, const gchar *value);
@@ -46,4 +47,6 @@ void
 gnome_cmd_data_get_color (const gchar *path, GdkColor *color);
 
 
+G_END_DECLS
+
 #endif //__LIBGCMD_DATA_H__
