@@ -14,11 +14,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_FILE_H__
 #define __GNOME_CMD_FILE_H__
 
+#include <config.h>
+
+
 #define GNOME_CMD_FILE(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_file_get_type (), GnomeCmdFile)
 #define GNOME_CMD_FILE_CLASS(klass) \
@@ -27,9 +31,16 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_file_get_type ())
 
 
-typedef struct _GnomeCmdFile GnomeCmdFile;
-typedef struct _GnomeCmdFileClass GnomeCmdFileClass;
-typedef struct _GnomeCmdFilePrivate    GnomeCmdFilePrivate;
+typedef struct _GnomeCmdFile        GnomeCmdFile;
+typedef struct _GnomeCmdFileClass   GnomeCmdFileClass;
+typedef struct _GnomeCmdFilePrivate GnomeCmdFilePrivate;
+typedef struct _GnomeCmdFileMetadata GnomeCmdFileMetadata;
+
+struct _GnomeCmdFileMetadata
+{
+    gboolean accessed;
+    gpointer metadata;
+};
 
 struct _GnomeCmdFile
 {
@@ -37,6 +48,15 @@ struct _GnomeCmdFile
 
     GnomeVFSFileInfo *info;
     GnomeCmdFilePrivate *priv;
+#ifdef HAVE_EXIF
+    GnomeCmdFileMetadata exif;
+#endif
+#ifdef HAVE_IPTC
+    GnomeCmdFileMetadata iptc;
+#endif
+#ifdef HAVE_LCMS
+    GnomeCmdFileMetadata icc;
+#endif
 };
 
 struct _GnomeCmdFileClass
@@ -44,10 +64,10 @@ struct _GnomeCmdFileClass
     GnomeCmdFileInfoClass parent_class;
 };
 
-
-#include "gnome-cmd-file.h"
 #include "gnome-cmd-dir.h"
 
+G_BEGIN_DECLS
+
 GtkType gnome_cmd_file_get_type (void);
 
 GnomeCmdFile *gnome_cmd_file_new (GnomeVFSFileInfo *info,
@@ -107,7 +127,7 @@ void gnome_cmd_file_show_cap_cut (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_cap_copy (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_cap_paste (GnomeCmdFile *finfo);
 
-//FIXME: Theese names sucks when we have a class called GnomeCmdFileList...
+//FIXME: These names suck when we have a class called GnomeCmdFileList...
 GList *gnome_cmd_file_list_copy (GList *files);
 void gnome_cmd_file_list_free (GList *files);
 void gnome_cmd_file_list_ref (GList *files);
@@ -121,4 +141,6 @@ void gnome_cmd_file_execute (GnomeCmdFile *finfo);
 
 gboolean gnome_cmd_file_needs_update (GnomeCmdFile *finfo);
 
-#endif //__GNOME_CMD_FILE_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_FILE_H__
