@@ -1,13 +1,13 @@
 /*
-    LibGViewer - GTK+ File Viewer library 
+    LibGViewer - GTK+ File Viewer library
     Copyright (C) 2006 Assaf Gordon
-    
+
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
 
     Partly based on "gtkhex.c" module from "GHex2" Project.
-	Author: Jaka Mocnik <jaka@gnu.org>
+    Author: Jaka Mocnik <jaka@gnu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -91,6 +91,7 @@ struct _TextRenderPrivate
 	int column ;
 	int max_column ;
 	offset_type current_offset ;
+	offset_type last_displayed_offset ;
 	TEXTDISPLAYMODE dispmode ;
 	gboolean hex_offset_display;
 	gchar *fixed_font_name;
@@ -120,7 +121,7 @@ struct _TextRenderPrivate
 	
 /* Gtk class related static functions */
 static void text_render_init (TextRender *w);
-static void text_render_class_init (TextRenderClass *class);
+static void text_render_class_init (TextRenderClass *klass);
 static void text_render_destroy (GtkObject *object);
 
 static void text_render_redraw(TextRender *w);
@@ -165,121 +166,121 @@ static void hex_mode_copy_to_clipboard(TextRender *obj, offset_type start_offset
 static offset_type hex_mode_pixel_to_offset( TextRender *obj, int x, int y, gboolean start_marker );
 
 /*****************************************
-	public functions
-	(defined in the header file)
+    public functions
+    (defined in the header file)
 *****************************************/
 GtkType text_render_get_type (void)
 {
-	static GtkType type = 0;
-	if (type == 0)	{
-		GtkTypeInfo info =
-		{
-			"TextRender",
-			sizeof (TextRender),
-			sizeof (TextRenderClass),
-			(GtkClassInitFunc) text_render_class_init,
-			(GtkObjectInitFunc) text_render_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL
-		};
-		type = gtk_type_unique (gtk_widget_get_type(), &info);
-	}
-	return type;
+    static GtkType type = 0;
+    if (type == 0)    {
+        GtkTypeInfo info =
+        {
+            "TextRender",
+            sizeof (TextRender),
+            sizeof (TextRenderClass),
+            (GtkClassInitFunc) text_render_class_init,
+            (GtkObjectInitFunc) text_render_init,
+            /* reserved_1 */ NULL,
+            /* reserved_2 */ NULL,
+            (GtkClassInitFunc) NULL
+        };
+        type = gtk_type_unique (gtk_widget_get_type(), &info);
+    }
+    return type;
 }
 
 GtkWidget*
 text_render_new (void)
 {
-	TextRender *w;
-	
-	w = gtk_type_new (text_render_get_type ());
-	
-	return GTK_WIDGET (w);
+    TextRender *w;
+
+    w = gtk_type_new (text_render_get_type ());
+
+    return GTK_WIDGET (w);
 }
 
 void text_render_set_h_adjustment (TextRender *obj, GtkAdjustment *adjustment)
 {
-	g_return_if_fail (obj != NULL);
-	g_return_if_fail (IS_TEXT_RENDER(obj));
+    g_return_if_fail (obj != NULL);
+    g_return_if_fail (IS_TEXT_RENDER(obj));
 
-	if (obj->priv->h_adjustment)
-	{
-		gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->h_adjustment), (gpointer) obj);
-		gtk_object_unref (GTK_OBJECT (obj->priv->h_adjustment));
-	}
+    if (obj->priv->h_adjustment)
+    {
+        gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->h_adjustment), (gpointer) obj);
+        gtk_object_unref (GTK_OBJECT (obj->priv->h_adjustment));
+    }
 
-	obj->priv->h_adjustment = adjustment;
-	gtk_object_ref (GTK_OBJECT (obj->priv->h_adjustment));
+    obj->priv->h_adjustment = adjustment;
+    gtk_object_ref (GTK_OBJECT (obj->priv->h_adjustment));
 
-	gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
-		      (GtkSignalFunc) text_render_h_adjustment_changed ,
-		      (gpointer) obj );
-	gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
-		      (GtkSignalFunc) text_render_h_adjustment_value_changed ,
-		      (gpointer) obj );
+    gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
+              (GtkSignalFunc) text_render_h_adjustment_changed ,
+              (gpointer) obj );
+    gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+              (GtkSignalFunc) text_render_h_adjustment_value_changed ,
+              (gpointer) obj );
 
-	obj->priv->old_h_adj_value = adjustment->value;
-	obj->priv->old_h_adj_lower = adjustment->lower;
-	obj->priv->old_h_adj_upper = adjustment->upper;
+    obj->priv->old_h_adj_value = adjustment->value;
+    obj->priv->old_h_adj_lower = adjustment->lower;
+    obj->priv->old_h_adj_upper = adjustment->upper;
 
-	text_render_h_adjustment_update (obj);
+    text_render_h_adjustment_update (obj);
 }
 
 void text_render_set_v_adjustment (TextRender *obj, GtkAdjustment *adjustment)
 {
-	g_return_if_fail (obj != NULL);
-	g_return_if_fail (IS_TEXT_RENDER(obj));
+    g_return_if_fail (obj != NULL);
+    g_return_if_fail (IS_TEXT_RENDER(obj));
 
-	if (obj->priv->v_adjustment)
-	{
-		gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->v_adjustment), (gpointer) obj);
-		gtk_object_unref (GTK_OBJECT (obj->priv->v_adjustment));
-	}
+    if (obj->priv->v_adjustment)
+    {
+        gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->v_adjustment), (gpointer) obj);
+        gtk_object_unref (GTK_OBJECT (obj->priv->v_adjustment));
+    }
 
-	obj->priv->v_adjustment = adjustment;
-	gtk_object_ref (GTK_OBJECT (obj->priv->v_adjustment));
+    obj->priv->v_adjustment = adjustment;
+    gtk_object_ref (GTK_OBJECT (obj->priv->v_adjustment));
 
-	gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
-		      (GtkSignalFunc) text_render_v_adjustment_changed ,
-		      (gpointer) obj );
-	gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
-		      (GtkSignalFunc) text_render_v_adjustment_value_changed ,
-		      (gpointer) obj );
+    gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
+              (GtkSignalFunc) text_render_v_adjustment_changed ,
+              (gpointer) obj );
+    gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+              (GtkSignalFunc) text_render_v_adjustment_value_changed ,
+              (gpointer) obj );
 
-	obj->priv->old_v_adj_value = adjustment->value;
-	obj->priv->old_v_adj_lower = adjustment->lower;
-	obj->priv->old_v_adj_upper = adjustment->upper;
+    obj->priv->old_v_adj_value = adjustment->value;
+    obj->priv->old_v_adj_lower = adjustment->lower;
+    obj->priv->old_v_adj_upper = adjustment->upper;
 
-	text_render_v_adjustment_update (obj);
+    text_render_v_adjustment_update (obj);
 }
 
-static void	
-text_render_class_init (TextRenderClass *class)
+static void
+text_render_class_init (TextRenderClass *klass)
 {
-	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-	
-	object_class = (GtkObjectClass*) class;
-	widget_class = (GtkWidgetClass*) class;
-	
-	parent_class = gtk_type_class (gtk_widget_get_type ());
-	
-	object_class->destroy = text_render_destroy;
-	
-	widget_class->scroll_event = text_render_scroll;
-	widget_class->button_press_event = text_render_button_press;
-	widget_class->button_release_event = text_render_button_release;
-	widget_class->motion_notify_event = text_render_motion_notify;
+    GtkObjectClass *object_class;
+    GtkWidgetClass *widget_class;
 
-	widget_class->expose_event = text_render_expose;
+    object_class = (GtkObjectClass*) klass;
+    widget_class = (GtkWidgetClass*) klass;
 
-	widget_class->size_request = text_render_size_request;
-	widget_class->size_allocate = text_render_size_allocate;
+    parent_class = gtk_type_class (gtk_widget_get_type ());
 
-	widget_class->realize = text_render_realize;
-	
-	text_render_signals[TEXT_STATUS_CHANGED] =
+    object_class->destroy = text_render_destroy;
+
+    widget_class->scroll_event = text_render_scroll;
+    widget_class->button_press_event = text_render_button_press;
+    widget_class->button_release_event = text_render_button_release;
+    widget_class->motion_notify_event = text_render_motion_notify;
+
+    widget_class->expose_event = text_render_expose;
+
+    widget_class->size_request = text_render_size_request;
+    widget_class->size_allocate = text_render_size_allocate;
+
+    widget_class->realize = text_render_realize;
+
+    text_render_signals[TEXT_STATUS_CHANGED] =
         gtk_signal_new ("text_status_changed",
             GTK_RUN_LAST,
             G_OBJECT_CLASS_TYPE (object_class),
@@ -602,7 +603,7 @@ static gboolean text_render_expose( GtkWidget *widget, GdkEventExpose *event )
 	ofs = w->priv->current_offset ;
 	y = 0 ;
 	
-	while (TRUE) {
+	while (1) {
 		offset_type eol_offset ;
 		
 		eol_offset = gv_get_end_of_line_offset(w->priv->dp, ofs);
@@ -622,6 +623,8 @@ static gboolean text_render_expose( GtkWidget *widget, GdkEventExpose *event )
 		
 	}
 	
+	w->priv->last_displayed_offset = ofs ;
+	
 	return FALSE;
 }
 
@@ -1145,13 +1148,13 @@ static guint text_render_filter_undisplayable_chars(TextRender* obj)
 		pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
 #if 0		
 		printf("char (%03d, %02x), utf8buf_len(%d) utf8((%02x %02x %02x %02x), width = %d\n",
-                i,i,
-                obj->priv->utf8buf_length,
-                obj->priv->utf8buf[0],
-                obj->priv->utf8buf[1],
-                obj->priv->utf8buf[2],
-                obj->priv->utf8buf[3],
-                logical_rect.width);
+			i,i,
+			obj->priv->utf8buf_length,
+			obj->priv->utf8buf[0],
+			obj->priv->utf8buf[1],
+			obj->priv->utf8buf[2],
+			obj->priv->utf8buf[3],
+			logical_rect.width);
 #endif
 
 		if (logical_rect.width==0) {
@@ -1431,6 +1434,47 @@ int text_render_get_fixed_limit(TextRender *w)
 	return w->priv->fixed_limit;
 }
 
+offset_type	text_render_get_current_offset(TextRender *w)
+{
+	g_return_val_if_fail(w!=NULL,0);
+	g_return_val_if_fail(IS_TEXT_RENDER(w),0);
+	
+	return w->priv->current_offset;
+}
+
+offset_type	text_render_get_last_displayed_offset(TextRender *w)
+{
+	g_return_val_if_fail(w!=NULL,0);
+	g_return_val_if_fail(IS_TEXT_RENDER(w),0);
+	
+	return w->priv->last_displayed_offset;
+}
+
+void text_render_ensure_offset_visible(TextRender *w, offset_type offset)
+{
+	g_return_if_fail(w!=NULL);
+	g_return_if_fail(IS_TEXT_RENDER(w));
+	
+	if ( offset < w->priv->current_offset || offset > w->priv->last_displayed_offset) {
+		offset = gv_align_offset_to_line_start(w->priv->dp, offset) ;
+		offset = gv_scroll_lines(w->priv->dp, offset, -w->priv->lines_displayed/2 );
+		
+		w->priv->current_offset = offset ;
+		text_render_redraw(w);
+		text_render_position_changed(w);
+	}
+}
+
+void text_render_set_marker(TextRender *w, offset_type start, offset_type end)
+{
+	g_return_if_fail(w!=NULL);
+	g_return_if_fail(IS_TEXT_RENDER(w)) ;
+	
+	w->priv->marker_start = start ;
+	w->priv->marker_end = end ;
+	text_render_redraw(w);
+}
+
 void text_render_set_encoding(TextRender *w, const char* encoding)
 {
 	g_return_if_fail(w!=NULL);
@@ -1619,7 +1663,7 @@ static void text_mode_copy_to_clipboard(TextRender *obj, offset_type start_offse
 		text_render_utf8_print_char(obj,value);
 	}
 	
-	gtk_clipboard_set_text(clip, (gchar *)obj->priv->utf8buf, obj->priv->utf8buf_length);
+	gtk_clipboard_set_text(clip, obj->priv->utf8buf, obj->priv->utf8buf_length);
 }
 
 static int text_mode_display_line(TextRender* w, int y, int column, offset_type start_of_line, offset_type end_of_line )
@@ -1864,7 +1908,7 @@ static void hex_mode_copy_to_clipboard(TextRender *obj, offset_type start_offset
 		text_render_utf8_printf(obj,"%02x ", (unsigned char)value);
 	}
 	
-	gtk_clipboard_set_text(clip, (gchar *)obj->priv->utf8buf, obj->priv->utf8buf_length);
+	gtk_clipboard_set_text(clip, obj->priv->utf8buf, obj->priv->utf8buf_length);
 }
 
 static int hex_mode_display_line(TextRender* w, int y, int column, offset_type start_of_line, offset_type end_of_line )
